@@ -11,7 +11,7 @@
 #include <iostream>
 #include <fstream>
 #include <sstream>
-#include "../util.h"
+#include "../staputil.h"
 #include "backends.h"
 #include "../cmdline.h"
 #include "utils.h"
@@ -382,7 +382,7 @@ public:
 
 response build_collection_rh::POST(const request &req)
 {
-    client_request_data *crd = new struct client_request_data;
+    client_request_data *crd = new client_request_data;
     if (crd == NULL) {
 	// Return an error.
 	server_error("500 - internal server error");
