@@ -11,7 +11,7 @@
 #include "parse.h"
 #include "session.h"
 #include "tapsets.h"
-#include "util.h"
+#include "staputil.h"
 #include <ext/stdio_filebuf.h>
 
 using namespace std;
