@@ -1,5 +1,5 @@
 void foo(void) {
-    asm("movl $0xbeefdead, %edx");
+    asm("movq $0x56781234beefdead, %rdx");
     return;
 }
 
