@@ -37,9 +37,9 @@ int main()
 
  syscall(__NR_utime, (char *)-1, &times );
 #ifdef __s390__
- //staptest// utime ([7]?[f]+, \[Sun Sep  9 01:46:40 2001, Wed May 18 03:33:20 2033]) = -NNNN
+ //staptest// utime (0x[7]?[f]+, \[Sun Sep  9 01:46:40 2001, Wed May 18 03:33:20 2033]) = -NNNN
 #else
- //staptest// utime ([f]+, \[Sun Sep  9 01:46:40 2001, Wed May 18 03:33:20 2033]) = -NNNN
+ //staptest// utime (0x[f]+, \[Sun Sep  9 01:46:40 2001, Wed May 18 03:33:20 2033]) = -NNNN
 #endif
 
  syscall(__NR_utime, "foobar", (struct utimbuf *)-1 );
@@ -52,9 +52,9 @@ int main()
 
   syscall(__NR_utimes, (char *)-1, tv);
 #ifdef __s390__
-  //staptest// utimes ([7]?[f]+, \[1000000000.001234\]\[2000000000.005678\])
+  //staptest// utimes (0x[7]?[f]+, \[1000000000.001234\]\[2000000000.005678\])
 #else
-  //staptest// utimes ([f]+, \[1000000000.001234\]\[2000000000.005678\])
+  //staptest// utimes (0x[f]+, \[1000000000.001234\]\[2000000000.005678\])
 #endif
 
   syscall(__NR_utimes, "foobar", (struct timeval *)-1);
@@ -77,9 +77,9 @@ int main()
 
   syscall(__NR_futimesat, AT_FDCWD, (char *)-1, tv);
 #ifdef __s390__
-  //staptest// futimesat (AT_FDCWD, [7]?[f]+, \[1000000000.001234\]\[2000000000.005678\]) = -NNNN
+  //staptest// futimesat (AT_FDCWD, 0x[7]?[f]+, \[1000000000.001234\]\[2000000000.005678\]) = -NNNN
 #else
-  //staptest// futimesat (AT_FDCWD, [f]+, \[1000000000.001234\]\[2000000000.005678\]) = -NNNN
+  //staptest// futimesat (AT_FDCWD, 0x[f]+, \[1000000000.001234\]\[2000000000.005678\]) = -NNNN
 #endif
 
   syscall(__NR_futimesat, AT_FDCWD, "foobar", (struct timeval *)-1);
@@ -90,7 +90,7 @@ int main()
 #endif
 #endif /* __NR_futimesat */
 
-#if defined(__NR_utimensat) && LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,22)
+#if defined(__NR_utimensat)
   ts[0].tv_sec = 1000000000;
   ts[0].tv_nsec = 123456789;
   ts[1].tv_sec = 2000000000;
@@ -113,9 +113,9 @@ int main()
 
   syscall(__NR_utimensat, AT_FDCWD, (char *)-1, ts, AT_SYMLINK_NOFOLLOW);
 #ifdef __s390__
-  //staptest// utimensat (AT_FDCWD, [7]?[f]+, \[UTIME_NOW\]\[UTIME_OMIT\], AT_SYMLINK_NOFOLLOW)
+  //staptest// utimensat (AT_FDCWD, 0x[7]?[f]+, \[UTIME_NOW\]\[UTIME_OMIT\], AT_SYMLINK_NOFOLLOW)
 #else
-  //staptest// utimensat (AT_FDCWD, [f]+, \[UTIME_NOW\]\[UTIME_OMIT\], AT_SYMLINK_NOFOLLOW)
+  //staptest// utimensat (AT_FDCWD, 0x[f]+, \[UTIME_NOW\]\[UTIME_OMIT\], AT_SYMLINK_NOFOLLOW)
 #endif
 
   syscall(__NR_utimensat, AT_FDCWD, "foobar", (struct timespec *)-1, AT_SYMLINK_NOFOLLOW);
