@@ -1,15 +1,29 @@
-/* COVERAGE: getcwd fstat stat lstat fstatat utime */
+/* COVERAGE: getcwd fstat stat lstat fstatat fstatat64 utime */
 /* COVERAGE: fstat64 stat64 lstat64 */
 /* COVERAGE: newfstat newfstatat newlstat newstat */
+/* COVERAGE: statx */
 #define _GNU_SOURCE
 #include <unistd.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <sys/syscall.h>
 #include <fcntl.h>
 #include <utime.h>
 #include <string.h>
 #include <time.h>
 #include <stdio.h>
+#include <sys/mman.h>
+
+#ifdef __NR_statx
+/* For struct statx */
+#include <linux/stat.h>
+/* The AT_STATX_FORCE_SYNC is defined within linux/fcntl.h,
+ * but including that would cause conflict with already included fcntl.h
+ */
+#ifndef AT_STATX_FORCE_SYNC
+#define AT_STATX_FORCE_SYNC 0x2000
+#endif
+#endif
 
 // To test for glibc support for fstatat():
 //
@@ -22,12 +36,28 @@
   (_XOPEN_SOURCE >= 700 || _POSIX_C_SOURCE >= 200809L \
    || defined(_ATFILE_SOURCE))
 
+#if !__GLIBC_PREREQ(2, 28)
+#ifdef __NR_statx
+static inline
+ssize_t statx(int dfd, const char *filename, unsigned flags,
+              unsigned int mask, struct statx *buffer)
+{
+        return syscall(__NR_statx, dfd, filename, flags, mask, buffer);
+}
+#endif
+#endif
+
 int main()
 {
   int fd;
   char cwd[128];
   struct stat sbuf;
   struct utimbuf ubuf;
+#ifdef __NR_statx
+  struct statx stx;
+#endif
+
+  mlockall(MCL_CURRENT);
 
   getcwd(cwd, 128);
   //staptest// getcwd (XXXX, 128) = NNNN
@@ -52,6 +82,35 @@ int main()
   //staptest// fstat (-1, 0x[f]+) = -NNNN
 #endif
 
+#ifdef __NR_statx
+  memset(&stx, 0xbf, sizeof(stx));
+  statx(AT_FDCWD, "foobar", AT_SYMLINK_NOFOLLOW, AT_STATX_FORCE_SYNC, &stx);
+  //staptest// statx (AT_FDCWD, "foobar", AT_SYMLINK_NOFOLLOW, AT_STATX_FORCE_SYNC, XXXX) = 0
+
+  statx((int)-1, "foobar", AT_SYMLINK_NOFOLLOW, AT_STATX_FORCE_SYNC, &stx);
+  //staptest// statx (-1, "foobar", AT_SYMLINK_NOFOLLOW, AT_STATX_FORCE_SYNC, XXXX) = -NNNN (EBADF)
+
+  statx(AT_FDCWD, (const char *)-1, AT_SYMLINK_NOFOLLOW, AT_STATX_FORCE_SYNC, &stx);
+#ifdef __s390__
+  //staptest// statx (AT_FDCWD, 0x[7]?[f]+, AT_SYMLINK_NOFOLLOW, AT_STATX_FORCE_SYNC, XXXX) = -NNNN (EFAULT)
+#else
+  //staptest// statx (AT_FDCWD, 0x[f]+, AT_SYMLINK_NOFOLLOW, AT_STATX_FORCE_SYNC, XXXX) = -NNNN (EFAULT)
+#endif
+
+  statx(AT_FDCWD, "foobar", (unsigned)-1, AT_STATX_FORCE_SYNC, &stx);
+  //staptest// statx (AT_FDCWD, "foobar", AT_SYMLINK_NOFOLLOW|AT_REMOVEDIR|AT_SYMLINK_FOLLOW|AT_NO_AUTOMOUNT|AT_EMPTY_PATH|XXXX, AT_STATX_FORCE_SYNC, XXXX) = -NNNN (EINVAL)
+
+  statx(AT_FDCWD, "foobar", AT_SYMLINK_NOFOLLOW, (unsigned)-1, &stx);
+  //staptest// statx (AT_FDCWD, "foobar", AT_SYMLINK_NOFOLLOW, 0x[f]+, XXXX) = NNNN
+
+  statx(AT_FDCWD, "foobar", AT_SYMLINK_NOFOLLOW, AT_STATX_FORCE_SYNC, (struct statx *)-1);
+#ifdef __s390__
+  //staptest// statx (AT_FDCWD, "foobar", AT_SYMLINK_NOFOLLOW, AT_STATX_FORCE_SYNC, 0x[7]?[f]+) = -NNNN (EFAULT)
+#else
+  //staptest// statx (AT_FDCWD, "foobar", AT_SYMLINK_NOFOLLOW, AT_STATX_FORCE_SYNC, 0x[f]+) = -NNNN (EFAULT)
+#endif
+#endif
+
   close(fd);
 
   stat("foobar", &sbuf);
@@ -59,9 +118,9 @@ int main()
 
   stat((char *)-1, &sbuf);
 #if defined(__s390__)
-  //staptest// stat ([7]?[f]+, XXXX) = -NNNN
+  //staptest// stat (0x[7]?[f]+, XXXX) = -NNNN
 #else
-  //staptest// [[[[stat ([f]+, XXXX!!!!fstatat (AT_FDCWD, [f]+, XXXX, 0x0]]]]) = -NNNN
+  //staptest// [[[[stat (0x[f]+, XXXX!!!!fstatat (AT_FDCWD, 0x[f]+, XXXX, 0x0]]]]) = -NNNN
 #endif
 
   // Here we specify -1 to both arguments, to avoid a SIGSEGV.
@@ -70,9 +129,9 @@ int main()
   // Notice we're not checking for 0x[f]+ here for the 2nd
   // argument. On RHEL[67] {x86_64,s390x}, for a 32-bit exe, glibc
   // substituted a real structure address (verified with strace).
-  //staptest// stat ([7]?[f]+, XXXX) = -NNNN
+  //staptest// stat (0x[7]?[f]+, XXXX) = -NNNN
 #else
-  //staptest// [[[[stat ([f]+, 0x[f]+!!!!fstatat (AT_FDCWD, [f]+, 0x[f]+, 0x0]]]]) = -NNNN
+  //staptest// [[[[stat (0x[f]+, 0x[f]+!!!!fstatat (AT_FDCWD, 0x[f]+, 0x[f]+, 0x0]]]]) = -NNNN
 #endif
 
   lstat("foobar", &sbuf);
@@ -80,9 +139,9 @@ int main()
 
   lstat((char *)-1, &sbuf);
 #if defined(__s390__)
-  //staptest// lstat ([7]?[f]+, XXXX) = -NNNN (EFAULT)
+  //staptest// lstat (0x[7]?[f]+, XXXX) = -NNNN (EFAULT)
 #else
-  //staptest// [[[[lstat ([f]+, XXXX!!!!fstatat (AT_FDCWD, [f]+, XXXX, AT_SYMLINK_NOFOLLOW]]]]) = -NNNN (EFAULT)
+  //staptest// [[[[lstat (0x[f]+, XXXX!!!!fstatat (AT_FDCWD, 0x[f]+, XXXX, AT_SYMLINK_NOFOLLOW]]]]) = -NNNN (EFAULT)
 #endif
 
   // Here we specify -1 to both arguments, to avoid a SIGSEGV.
@@ -91,9 +150,9 @@ int main()
   // Notice we're not checking for 0x[f]+ here for the 2nd
   // argument. On RHEL[67] {x86_64,s390x}, for a 32-bit exe, glibc
   // substituted a real structure address (verified with strace).
-  //staptest// lstat ([7]?[f]+, XXXX) = -NNNN
+  //staptest// lstat (0x[7]?[f]+, XXXX) = -NNNN
 #else
-  //staptest// [[[[lstat ([f]+, 0x[f]+!!!!fstatat (AT_FDCWD, [f]+, 0x[f]+, AT_SYMLINK_NOFOLLOW]]]]) = -NNNN
+  //staptest// [[[[lstat (0x[f]+, 0x[f]+!!!!fstatat (AT_FDCWD, 0x[f]+, 0x[f]+, AT_SYMLINK_NOFOLLOW]]]]) = -NNNN
 #endif
 
 #if GLIBC_SUPPORT
@@ -105,9 +164,9 @@ int main()
 
   fstatat(AT_FDCWD, (char *)-1, &sbuf, AT_SYMLINK_NOFOLLOW);
 #if defined(__s390__)
-  //staptest// fstatat (AT_FDCWD, [7]?[f]+, XXXX, AT_SYMLINK_NOFOLLOW) = -NNNN (EFAULT)
+  //staptest// fstatat (AT_FDCWD, 0x[7]?[f]+, XXXX, AT_SYMLINK_NOFOLLOW) = -NNNN (EFAULT)
 #else
-  //staptest// fstatat (AT_FDCWD, [f]+, XXXX, AT_SYMLINK_NOFOLLOW) = -NNNN (EFAULT)
+  //staptest// fstatat (AT_FDCWD, 0x[f]+, XXXX, AT_SYMLINK_NOFOLLOW) = -NNNN (EFAULT)
 #endif
 
   // Try to avoid a SIGSEGV.
@@ -151,23 +210,18 @@ int main()
   ubuf.modtime = 1135641600;
   utime((char *)-1, &ubuf);
 #if defined(__aarch64__)
-  //staptest// utimensat (AT_FDCWD, [f]+, \[1.[0]+\]\[1135641600.[0]+\], 0x0) = -NNNN
+  //staptest// utimensat (AT_FDCWD, 0x[f]+, \[1.[0]+\]\[1135641600.[0]+\], 0x0) = -NNNN
 #elif defined(__ia64__) || defined(__arm__)
-  //staptest// utimes ([f]+, \[1.000000\]\[1135641600.000000\]) = -NNNN
+  //staptest// utimes (0x[f]+, \[1.000000\]\[1135641600.000000\]) = -NNNN
 #elif defined(__s390__)
-  //staptest// utime ([7]?[f]+, \[Thu Jan  1 00:00:01 1970, Tue Dec 27 00:00:00 2005\]) = -NNNN
+  //staptest// utime (0x[7]?[f]+, \[Thu Jan  1 00:00:01 1970, Tue Dec 27 00:00:00 2005\]) = -NNNN
 #else
-  //staptest// utime ([f]+, \[Thu Jan  1 00:00:01 1970, Tue Dec 27 00:00:00 2005\]) = -NNNN
+  //staptest// utime (0x[f]+, \[Thu Jan  1 00:00:01 1970, Tue Dec 27 00:00:00 2005\]) = -NNNN
 #endif
 
-#if defined(__ia64__) || defined(__arm__) || defined(__aarch64__)
   // Avoid a SIGSEGV by specifying NULL, not -1.
   utime("foobar", (struct utimbuf *)NULL);
   //staptest// [[[[utimes ("foobar", NULL!!!!utimensat (AT_FDCWD, "foobar", NULL, 0x0]]]]) = NNNN
-#else
-  utime("foobar", (struct utimbuf *)-1);
-  //staptest// utime ("foobar", \[Thu Jan  1 00:00:00 1970, Thu Jan  1 00:00:00 1970\]) = -NNNN
-#endif
 
   return 0;
 }
