@@ -11,38 +11,12 @@
 
 #include "staptree.h"
 #include "parse.h"
-#include <iostream>
-#include <fstream>
 #include <string>
 
 
 // ------------------------------------------------------------------------
 
-// Output context for systemtap translation, intended to allow
-// pretty-printing.
-class translator_output
-{
-  char *buf;
-  std::ofstream* o2;
-  std::ostream& o;
-  unsigned tablevel;
-
-public:
-  std::string filename;
-
-  translator_output (std::ostream& file);
-  translator_output (const std::string& filename, size_t bufsize = 8192);
-  ~translator_output ();
-
-  std::ostream& newline (int indent = 0);
-  void indent (int indent = 0);
-  void assert_0_indent () { o << std::flush; assert (tablevel == 0); }
-  std::ostream& line();
-
-  std::ostream::pos_type tellp() { return o.tellp(); }
-  std::ostream& seekp(std::ostream::pos_type p) { return o.seekp(p); }
-};
-
+#include "translator-output.h" // translator_output moved to separate file
 
 // An unparser instance is in charge of emitting code for generic
 // probe bodies, functions, globals.
